@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -88,12 +88,14 @@ class TabBar(E5WheelTabBar):
             mimeData = QMimeData()
             index = self.tabAt(event.pos())
             mimeData.setText(self.tabText(index))
-            mimeData.setData("action", "tab-reordering")
-            mimeData.setData("tabbar-id", str(id(self)))
+            mimeData.setData("action", b"tab-reordering")
+            mimeData.setData("tabbar-id", str(id(self)).encode("utf-8"))
             mimeData.setData(
                 "source-index",
                 QByteArray.number(self.tabAt(self.__dragStartPos)))
-            mimeData.setData("tabwidget-id", str(id(self.parentWidget())))
+            mimeData.setData(
+                "tabwidget-id",
+                str(id(self.parentWidget())).encode("utf-8"))
             drag.setMimeData(mimeData)
             if event.modifiers() == Qt.KeyboardModifiers(Qt.ShiftModifier):
                 drag.exec_(Qt.DropActions(Qt.CopyAction))
@@ -110,7 +112,7 @@ class TabBar(E5WheelTabBar):
         mimeData = event.mimeData()
         formats = mimeData.formats()
         if "action" in formats and \
-           mimeData.data("action") == "tab-reordering" and \
+           mimeData.data("action") == b"tab-reordering" and \
            "tabbar-id" in formats and \
            "source-index" in formats and \
            "tabwidget-id" in formats:
@@ -125,7 +127,7 @@ class TabBar(E5WheelTabBar):
         """
         mimeData = event.mimeData()
         oldID = int(mimeData.data("tabbar-id"))
-        fromIndex = mimeData.data("source-index").toInt()[0]
+        fromIndex = int(mimeData.data("source-index"))
         toIndex = self.tabAt(event.pos())
         if oldID != id(self):
             parentID = int(mimeData.data("tabwidget-id"))
@@ -697,7 +699,7 @@ class TabWidget(E5TabWidget):
         self.vm.newEditor()
 
 
-class Tabview(QSplitter, ViewManager):
+class Tabview(ViewManager):
     """
     Class implementing a tabbed viewmanager class embedded in a splitter.
     
@@ -760,22 +762,34 @@ class Tabview(QSplitter, ViewManager):
         """
         self.tabWidgets = []
         
-        QSplitter.__init__(self, parent)
+        self.__splitter = QSplitter(parent)
         ViewManager.__init__(self)
+        self.__splitter.setChildrenCollapsible(False)
+        
         tw = TabWidget(self)
-        self.addWidget(tw)
+        self.__splitter.addWidget(tw)
         self.tabWidgets.append(tw)
         self.currentTabWidget = tw
         self.currentTabWidget.showIndicator(True)
         tw.currentChanged.connect(self.__currentChanged)
         tw.installEventFilter(self)
         tw.tabBar().installEventFilter(self)
-        self.setOrientation(Qt.Vertical)
+        self.__splitter.setOrientation(Qt.Vertical)
         self.__inRemoveView = False
         
         self.maxFileNameChars = Preferences.getUI(
             "TabViewManagerFilenameLength")
         self.filenameOnly = Preferences.getUI("TabViewManagerFilenameOnly")
+    
+    def mainWidget(self):
+        """
+        Public method to return a reference to the main Widget of a
+        specific view manager subclass.
+        
+        @return reference to the main widget
+        @rtype QWidget
+        """
+        return self.__splitter
         
     def canCascade(self):
         """
@@ -856,20 +870,26 @@ class Tabview(QSplitter, ViewManager):
             self.changeCaption.emit("")
         self.editorChangedEd.emit(aw)
         
-    def _addView(self, win, fn=None, noName=""):
+    def _addView(self, win, fn=None, noName="", next=False):
         """
         Protected method to add a view (i.e. window).
         
         @param win editor assembly to be added
         @param fn filename of this editor (string)
         @param noName name to be used for an unnamed editor (string)
+        @param next flag indicating to add the view next to the current
+            view (bool)
         """
         editor = win.getEditor()
         if fn is None:
             if not noName:
                 self.untitledCount += 1
                 noName = self.tr("Untitled {0}").format(self.untitledCount)
-            self.currentTabWidget.addTab(win, noName)
+            if next:
+                index = self.currentTabWidget.currentIndex() + 1
+                self.currentTabWidget.insertWidget(index, win, noName)
+            else:
+                self.currentTabWidget.addTab(win, noName)
             editor.setNoName(noName)
         else:
             if self.filenameOnly:
@@ -880,7 +900,11 @@ class Tabview(QSplitter, ViewManager):
                 txt = "...{0}".format(txt[-self.maxFileNameChars:])
             if not QFileInfo(fn).isWritable():
                 txt = self.tr("{0} (ro)").format(txt)
-            self.currentTabWidget.addTab(win, txt)
+            if next:
+                index = self.currentTabWidget.currentIndex() + 1
+                self.currentTabWidget.insertWidget(index, win, txt)
+            else:
+                self.currentTabWidget.addTab(win, txt)
             index = self.currentTabWidget.indexOf(win)
             self.currentTabWidget.setTabToolTip(index, fn)
         self.currentTabWidget.setCurrentWidget(win)
@@ -1053,7 +1077,7 @@ class Tabview(QSplitter, ViewManager):
         """
         tw = TabWidget(self)
         tw.show()
-        self.addWidget(tw)
+        self.__splitter.addWidget(tw)
         self.tabWidgets.append(tw)
         self.currentTabWidget.showIndicator(False)
         self.currentTabWidget = self.tabWidgets[-1]
@@ -1061,11 +1085,11 @@ class Tabview(QSplitter, ViewManager):
         tw.currentChanged.connect(self.__currentChanged)
         tw.installEventFilter(self)
         tw.tabBar().installEventFilter(self)
-        if self.orientation() == Qt.Horizontal:
+        if self.__splitter.orientation() == Qt.Horizontal:
             size = self.width()
         else:
             size = self.height()
-        self.setSizes(
+        self.__splitter.setSizes(
             [int(size / len(self.tabWidgets))] * len(self.tabWidgets))
         self.splitRemoveAct.setEnabled(True)
         self.nextSplitAct.setEnabled(True)
@@ -1093,7 +1117,14 @@ class Tabview(QSplitter, ViewManager):
                 self.tabWidgets.remove(tw)
                 tw.close()
                 self.currentTabWidget = self.tabWidgets[i]
-                self.currentTabWidget.showIndicator(True)
+                for tw in self.tabWidgets:
+                    tw.showIndicator(tw == self.currentTabWidget)
+                if self.currentTabWidget is not None:
+                    assembly = self.currentTabWidget.currentWidget()
+                    if assembly is not None:
+                        editor = assembly.getEditor()
+                        if editor is not None:
+                            editor.setFocus(Qt.OtherFocusReason)
                 if len(self.tabWidgets) == 1:
                     self.splitRemoveAct.setEnabled(False)
                     self.nextSplitAct.setEnabled(False)
@@ -1108,7 +1139,7 @@ class Tabview(QSplitter, ViewManager):
         
         @return orientation of the split (Qt.Horizontal or Qt.Vertical)
         """
-        return self.orientation()
+        return self.__splitter.orientation()
         
     def setSplitOrientation(self, orientation):
         """
@@ -1117,7 +1148,7 @@ class Tabview(QSplitter, ViewManager):
         @param orientation orientation of the split
                 (Qt.Horizontal or Qt.Vertical)
         """
-        self.setOrientation(orientation)
+        self.__splitter.setOrientation(orientation)
         
     def nextSplit(self):
         """
